CS_R

Type Alias CS_R 

pub type CS_R = R<u8, CS_A>;
Reader of field CS

Aliased Type

pub struct CS_R { /* private fields */ }

Implementations

Source

impl CS_R

pub fn variant(&self) -> Variant<u8, CS_A>

Get enumerated values variant

pub fn is_sysclk(&self) -> bool

Checks if the value of the field is SYSCLK

pub fn is_altclk(&self) -> bool

Checks if the value of the field is ALTCLK