pub type CS_R = R<u8, CS_A>;
Reader of field CS
CS
pub struct CS_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is SYSCLK
SYSCLK
Checks if the value of the field is ALTCLK
ALTCLK